@@ -3,7 +3,7 @@ use byteorder::LittleEndian;
 use crate::io::BufMut;
 use crate::mysql::io::BufMutExt;
 use crate::mysql::protocol::{Capabilities, Encode};
-use crate::mysql::types::MySqlTypeMetadata;
+use crate::mysql::types::MySqlTypeInfo;
 
 bitflags::bitflags! {
     // https://dev.mysql.com/doc/dev/mysql-server/8.0.12/mysql__com_8h.html#a3e5e9e744ff6f7b989a604fd669977da
@@ -23,7 +23,7 @@ pub struct ComStmtExecute<'a> {
     pub cursor: Cursor,
     pub params: &'a [u8],
     pub null_bitmap: &'a [u8],
-    pub param_types: &'a [MySqlTypeMetadata],
+    pub param_types: &'a [MySqlTypeInfo],
 }
 
 impl Encode for ComStmtExecute<'_> {
@@ -49,7 +49,7 @@ impl Encode for ComStmtExecute<'_> {
 
             for ty in self.param_types {
                 // field type : byte<1>
-                buf.put_u8(ty.r#type.0);
+                buf.put_u8(ty.id.0);
 
                 // parameter flag : byte<1>
                 buf.put_u8(if ty.is_unsigned { 0x80 } else { 0 });
